| Title: | Mating Environmental Designs |
|---|---|
| Description: | In breeding experiments, mating environmental (ME) designs are very popular as mating designs are directly implemented in the field environment using block or row-column designs. Here, three functions are given related to three new methods which will generate mating diallel cross designs (Hinkelmann and Kempthorne, 1963<doi:10.2307/2333899>) or mating environmental (ME) designs along with design parameters, C matrix, eigenvalues (EVs), degree of fractionations (DF) and canonical efficiency factor (CEF). Another one function is added to check the properties of a given ME diallel cross design. |
| Authors: | Ashutosh Dalal [aut, cre], Cini Varghese [aut, ctb], Rajender Parsad [aut, ctb], Mohd Harun [aut, ctb] |
| Maintainer: | Ashutosh Dalal <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0.1 |
| Built: | 2026-05-28 10:48:31 UTC |
| Source: | https://github.com/cran/MEDesigns |
Checking the Properties of a ME-PDC
CheckME_Diallel(design)CheckME_Diallel(design)
design |
Provide a ME-PDC |
Generates parameters of the designs along with C matrix, eigenvalues (EVs), degree of fractionations (DF) and canonical efficiency factor (CEF).
library(MEDesigns) design<-ME_PDC1(10)$ME_PDC CheckME_Diallel(design)library(MEDesigns) design<-ME_PDC1(10)$ME_PDC CheckME_Diallel(design)
ME-CDCs for Even Number of Lines
ME_CDC(lines)ME_CDC(lines)
lines |
Number of Lines >=6 |
ME-CDCs for an even number of lines along with their parameters, C matrices, eigenvalues (EVs) and canonical efficiency factor (CEF).
library(MEDesigns) ME_CDC(6)library(MEDesigns) ME_CDC(6)
ME-PDCs for Even Number of Lines
ME_PDC1(lines)ME_PDC1(lines)
lines |
Number of Lines >=6 |
ME-PDCs for an even number of lines along with their parameters, C matrices, eigenvalues (EVs), degree of fractionations (DF) and canonical efficiency factor (CEF).
library(MEDesigns) ME_PDC1(6)library(MEDesigns) ME_PDC1(6)
ME PDCs for Composite Number of Lines
ME_PDC2(p, q)ME_PDC2(p, q)
p |
Any value (p>=3) |
q |
Any value (q>=3) |
This function will provide ME-PDCs for a composite number, v(= pq) along with basic parameters, C matrix, eigenvalues (EVs), degree of fractionations (DF) and canonical efficiency factor (CEF).
library(MEDesigns) ME_PDC2(3,3)library(MEDesigns) ME_PDC2(3,3)
For a given field data it will provide analysis result through ANOVA table including gca and sca effect analysis.
MEBanalysis(data)MEBanalysis(data)
data |
Columns of dataset should be in order of block, line1,line2, cross number and response. |
Returns the ANOVA table of gca and sca effect analysis.
library(MEDesigns) MEBanalysis(MEdata)library(MEDesigns) MEBanalysis(MEdata)
This is a sample dataset for user.
data("MEdata")data("MEdata")
A data frame with 40 observations on the following 5 variables.
blocka numeric vector
line1a numeric vector
line2a numeric vector
cross_noa numeric vector
ylda numeric vector
data(MEdata)data(MEdata)